@@ -344,8 +344,8 @@ void KGrSLDialog::slSetGames (int cIndex)
     sortOrder1 << 'N' << 'C' << 'T';
     sortOrder2 << 'T' << 'K';
 
-    for (char sortItem1 : qAsConst(sortOrder1)) {
-        for (char sortItem2 : qAsConst(sortOrder2)) {
+    for (char sortItem1 : std::as_const(sortOrder1)) {
+        for (char sortItem2 : std::as_const(sortOrder2)) {
             for (i = 0; i < imax; ++i) {
                 if ((myGameList.at (i)->skill == sortItem1) &&
                     (myGameList.at (i)->rules == sortItem2)) {
